/*
	Functions and classes for use with SWIG to generate scripting
	language wrapper for IRT Command Language (Icl).
	
	IRT Command Language (Icl)
	http://www.b-a-h.com/software/icl

	Author(s): Brad Hanson (http://www.b-a-h.com/)
	See the file LICENSE for information on usage and redistribution.

	Copyright (c) 2000-2002, Bradley A. Hanson
	
*/

#ifndef SWIGEPDIRM_H_
#define SWIGEPDIRM_H_

#ifdef ETIRM_NO_DIR_PREFIX
#include "swig_etirm.h"
#else
#include "etirm/swig_etirm.h"
#endif

#ifndef SWIG
namespace etirm {
#endif

// Return base examinee group
int get_base_group();

// Change base examinee group
void set_base_group(int group);

// Set logistic scaling constant (D=1.7 make logistic curve close to normal)
void set_default_D(double D);

// Change default model used in creating item objects for dichotomous items
void set_default_model_dichtomous(IRTModel irtModel);

// Change default model used in creating item objects for dichotomous items
void set_default_model_polytomous(IRTModel irtModel);

// Set model used for item
void item_set_model(int itemno, IRTModel irtModel);

// Compute starting values for item parameters
int item_3PL_starting_values(int use_all = 0, int item_all = 0, int_vector *ilist3 = 0);

// Initialize run
// nitems		Total number of test items.
// ntheta		Number of discrete categories in latent variable distribution
// ngroup		Number of examinee groups. If > 1 than multiple group estimation is used
// ilist4		Vector containing number of response categories for each items (1 = dichotomous
//				item modeled by dichotomous model, >2 = polytomous item with that number of
//				response categories)
// dlist5		Vector containing minimum and maximum points to use for discrete 
//				latent variable distribution.
// uniquePoints If nonzero then unique latent distribution points are used for each examinee group
void new_items_dist(int nitems, int ntheta = 40, int ngroups = 1, int_vector *ilist4 = 0, double_vector *dlist5 = 0,
	int uniquePoints = 0);

// release memory allocated for run in new_epdirm
void delete_items_dist();

// Change default item parameter priors used in creating item objects
void set_default_prior(const char *param, const char *priortype, double_vector *priorparam);

// Return type of default prior for one item parameter (normal, lognormal, beta, none)
const char *get_default_prior_type(const char *paramname);

// Return vector of parameters of default prior for one item parameter
double_vector *get_default_prior_param(const char *paramname);

// Set seed of random number generator used for simulating from a normal distribution
void normal_seed(unsigned long seed);

// Return a generated number from a normal distribution with the specified mean and s.d.
double rand_normal(double mean = 0.0, double sd = 1.0);

#ifndef SWIG
} // namespace etirm
#endif

#endif
